==> 1.2025.316.6.tar.gz: OBJECTS/gen/chrome/browser/resources/settings/tsc/your_saved_info_page/your_saved_info_page_index.js <==
// Copyright 2025 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
/**
 * @fileoverview
 * 'settings-your-saved-info-page-index' is the settings page containing
 * settings for passwords, payment methods, addresses and more.
 */
import 'chrome://resources/cr_elements/cr_view_manager/cr_view_manager.js';
import '/shared/settings/prefs/prefs.js';
import './your_saved_info_page.js';
import '../settings_shared.css.js';
import { PolymerElement } from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
import { routes } from '../route.js';
import { RouteObserverMixin } from '../router.js';
import { SearchableViewContainerMixin } from '../settings_page/searchable_view_container_mixin.js';
import { getTemplate } from './your_saved_info_page_index.html.js';
const SettingsYourSavedInfoPageIndexElementBase = SearchableViewContainerMixin(RouteObserverMixin(PolymerElement));
export class SettingsYourSavedInfoPageIndexElement extends SettingsYourSavedInfoPageIndexElementBase {
    static get is() {
        return 'settings-your-saved-info-page-index';
    }
    static get template() {
        return getTemplate();
    }
    static get properties() {
        return {
            prefs: Object,
        };
    }
    currentRouteChanged(newRoute, oldRoute) {
        super.currentRouteChanged(newRoute, oldRoute);
        // Need to wait for currentRouteChanged observers on child views to run
        // first, before switching views.
        queueMicrotask(() => {
            switch (newRoute) {
                case routes.YOUR_SAVED_INFO:
                    this.$.viewManager.switchView('parent', 'no-animation', 'no-animation');
                    break;
                case routes.BASIC:
                    // Switch back to the default views in case they are part of search
                    // results.
                    this.$.viewManager.switchView('parent', 'no-animation', 'no-animation');
                    break;
                default:
                    // Nothing to do. Other parent elements are responsible for updating
                    // the displayed contents.
                    break;
            }
        });
    }
}
customElements.define(SettingsYourSavedInfoPageIndexElement.is, SettingsYourSavedInfoPageIndexElement);

==> 1.2025.344.7.tar.gz: OBJECTS/gen/chrome/browser/resources/settings/tsc/your_saved_info_page/your_saved_info_page_index.js <==
// Copyright 2025 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
/**
 * @fileoverview
 * 'settings-your-saved-info-page-index' is the settings page containing
 * settings for passwords, payment methods, addresses and more.
 */
import 'chrome://resources/cr_elements/cr_view_manager/cr_view_manager.js';
import '/shared/settings/prefs/prefs.js';
import './your_saved_info_page.js';
import '../settings_shared.css.js';
import { PolymerElement } from 'chrome://resources/polymer/v3_0/polymer/polymer_bundled.min.js';
import { routes } from '../route.js';
import { RouteObserverMixin } from '../router.js';
import { SearchableViewContainerMixin } from '../settings_page/searchable_view_container_mixin.js';
import { getTemplate } from './your_saved_info_page_index.html.js';
const SettingsYourSavedInfoPageIndexElementBase = SearchableViewContainerMixin(RouteObserverMixin(PolymerElement));
export class SettingsYourSavedInfoPageIndexElement extends SettingsYourSavedInfoPageIndexElementBase {
    static get is() {
        return 'settings-your-saved-info-page-index';
    }
    static get template() {
        return getTemplate();
    }
    static get properties() {
        return {
            prefs: Object,
        };
    }
    currentRouteChanged(newRoute, oldRoute) {
        super.currentRouteChanged(newRoute, oldRoute);
        // Need to wait for currentRouteChanged observers on child views to run
        // first, before switching views.
        queueMicrotask(() => {
            switch (newRoute) {
                case routes.YOUR_SAVED_INFO:
                    this.$.viewManager.switchView('parent', 'no-animation', 'no-animation');
                    break;
                case routes.BASIC:
                    // Switch back to the default views in case they are part of search
                    // results.
                    this.$.viewManager.switchView('parent', 'no-animation', 'no-animation');
                    break;
                case routes.ADDRESSES:
                    this.$.viewManager.switchView('addresses', 'no-animation', 'no-animation');
                    break;
                // 
                case routes.PASSKEYS:
                    this.$.viewManager.switchView('passkeys', 'no-animation', 'no-animation');
                    break;
                // 
                case routes.PAYMENTS:
                    this.$.viewManager.switchView('payments', 'no-animation', 'no-animation');
                    break;
                default:
                    // Nothing to do. Other parent elements are responsible for updating
                    // the displayed contents.
                    break;
            }
        });
    }
}
customElements.define(SettingsYourSavedInfoPageIndexElement.is, SettingsYourSavedInfoPageIndexElement);
